@@ -185,9 +185,8 @@ hevcc_c::parse_sei_list() {
   if (size == 100)
     return true;
 
-  unsigned char *newsei = (unsigned char *)safemalloc(size);
-  memset(newsei, 0, sizeof(char) * (size));
-  memory_cptr mcptr_newsei(new memory_c(newsei, size, true));
+  auto mcptr_newsei = memory_c::alloc(size);
+  auto newsei       = mcptr_newsei->get_buffer();
   bit_writer_c w(newsei, size);
   mm_mem_io_c byte_writer{newsei, static_cast<uint64_t>(size), 100};
 
@@ -940,10 +939,9 @@ slice_info_t::dump()
 bool
 parse_vps(memory_cptr const &buffer,
           vps_info_t &vps) {
-  int size              = buffer->get_size();
-  unsigned char *newvps = (unsigned char *)safemalloc(size + 100);
-  memset(newvps, 0, sizeof(char) * (size+100));
-  memory_cptr mcptr_newvps(new memory_c(newvps, size + 100, true));
+  auto size         = buffer->get_size();
+  auto mcptr_newvps = memory_c::alloc(size + 100);
+  auto newvps       = mcptr_newvps->get_buffer();
   bit_reader_c r(buffer->get_buffer(), size);
   bit_writer_c w(newvps, size + 100);
   unsigned int i, j;
@@ -1017,9 +1015,9 @@ parse_sps(memory_cptr const &buffer,
           sps_info_t &sps,
           std::vector<vps_info_t> &m_vps_info_list,
           bool keep_ar_info) {
-  int size              = buffer->get_size();
-  unsigned char *newsps = (unsigned char *)safemalloc(size + 100);
-  memory_cptr mcptr_newsps(new memory_c(newsps, size + 100, true));
+  auto size         = buffer->get_size();
+  auto mcptr_newsps = memory_c::alloc(size + 100);
+  auto newsps       = mcptr_newsps->get_buffer();
   bit_reader_c r(buffer->get_buffer(), size);
   bit_writer_c w(newsps, size + 100);
   unsigned int i;
@@ -1466,8 +1464,8 @@ es_parser_c::add_bytes(unsigned char *buffer,
 
       if (0 != marker_size) {
         if (-1 != previous_pos) {
-          int new_size = cursor.get_position() - marker_size - previous_pos - previous_marker_size;
-          memory_cptr nalu(new memory_c(safemalloc(new_size), new_size, true));
+          auto new_size = cursor.get_position() - marker_size - previous_pos - previous_marker_size;
+          auto nalu     = memory_c::alloc(new_size);
           cursor.copy(nalu->get_buffer(), previous_pos + previous_marker_size, new_size);
           m_parsed_position = previous_parsed_pos + previous_pos;
           handle_nalu(nalu);
@@ -1493,7 +1491,7 @@ es_parser_c::add_bytes(unsigned char *buffer,
 
   int new_size = cursor.get_size() - previous_pos;
   if (0 != new_size) {
-    m_unparsed_buffer = memory_cptr(new memory_c(safemalloc(new_size), new_size, true));
+    m_unparsed_buffer = memory_c::alloc(new_size);
     cursor.copy(m_unparsed_buffer->get_buffer(), previous_pos, new_size);
 
   } else
@@ -1524,26 +1522,6 @@ es_parser_c::add_timecode(int64_t timecode) {
   ++m_stats.num_timecodes_in;
 }
 
-void
-es_parser_c::write_nalu_size(unsigned char *buffer,
-                             size_t size,
-                             int this_nalu_size_length)
-  const {
-  unsigned int nalu_size_length = -1 == this_nalu_size_length ? m_nalu_size_length : this_nalu_size_length;
-
-  if (!m_ignore_nalu_size_length_errors && (size >= ((uint64_t)1 << (nalu_size_length * 8)))) {
-    unsigned int required_bytes = nalu_size_length + 1;
-    while (size >= (1u << (required_bytes * 8)))
-      ++required_bytes;
-
-    throw nalu_size_length_x(required_bytes);
-  }
-
-  unsigned int i;
-  for (i = 0; i < nalu_size_length; i++)
-    buffer[i] = (size >> (8 * (nalu_size_length - 1 - i))) & 0xff;
-}
-
 void
 es_parser_c::flush_incomplete_frame() {
   if (!m_have_incomplete_frame || !m_hevcc_ready)
@@ -1584,7 +1562,7 @@ es_parser_c::handle_slice_nalu(memory_cptr const &nalu) {
     memory_c &mem = *(m_incomplete_frame.m_data.get());
     int offset    = mem.get_size();
     mem.resize(offset + m_nalu_size_length + nalu->get_size());
-    write_nalu_size(mem.get_buffer() + offset, nalu->get_size());
+    mtx::mpeg::write_nalu_size(mem.get_buffer() + offset, nalu->get_size(), m_nalu_size_length, m_ignore_nalu_size_length_errors);
     memcpy(mem.get_buffer() + offset + m_nalu_size_length, nalu->get_buffer(), nalu->get_size());
 
     return;
@@ -1780,7 +1758,8 @@ es_parser_c::handle_pps_nalu(memory_cptr const &nalu) {
 
 void
 es_parser_c::handle_sei_nalu(memory_cptr const &nalu) {
-  parse_sei(mpeg::nalu_to_rbsp(nalu), m_user_data);
+  if (parse_sei(mpeg::nalu_to_rbsp(nalu), m_user_data))
+    m_extra_data.push_back(create_nalu_with_size(nalu));
 }
 
 void
@@ -2087,8 +2066,6 @@ es_parser_c::cleanup() {
       ++m_stats.num_timecodes_generated;
     }
 
-    if (frame_itr->m_start == 1033333333)
-      mxinfo("muh\n");
     frame_itr->m_end = frame_itr->m_start + duration_for(frame_itr->m_si);
 
     previous_frame_itr = frame_itr;
@@ -2127,28 +2104,12 @@ es_parser_c::cleanup() {
 memory_cptr
 es_parser_c::create_nalu_with_size(const memory_cptr &src,
                                    bool add_extra_data) {
-  int final_size = m_nalu_size_length + src->get_size(), offset = 0, size;
-  unsigned char *buffer;
-
-  if (add_extra_data) {
-    for (auto &mem : m_extra_data)
-      final_size += mem->get_size();
-    buffer = (unsigned char *)safemalloc(final_size);
-
-    for (auto &mem : m_extra_data) {
-      memcpy(buffer + offset, mem->get_buffer(), mem->get_size());
-      offset += mem->get_size();
-    }
+  auto nalu = mtx::mpeg::create_nalu_with_size(src, m_nalu_size_length, add_extra_data ? m_extra_data : std::vector<memory_cptr>{} );
 
+  if (add_extra_data)
     m_extra_data.clear();
-  } else
-    buffer = (unsigned char *)safemalloc(final_size);
 
-  size = src->get_size();
-  write_nalu_size(buffer + offset, size);
-  memcpy(buffer + offset + m_nalu_size_length, src->get_buffer(), size);
-
-  return memory_cptr(new memory_c(buffer, final_size, true));
+  return nalu;
 }
 
 memory_cptr
