@@ -29,6 +29,8 @@ char const * const codec_private_data              = "codec_private_data";
 char const * const codec_private_length            = "codec_private_length";            // track unsigned-integer
 char const * const content_encoding_algorithms     = "content_encoding_algorithms";     // track ascii-string
 char const * const cropping                        = "cropping";                        // track ascii-string format:
+char const * const date_local                      = "date_local";                      // container ascii-string format:^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}([+-]\d{2}:\d{2}|Z)$
+char const * const date_utc                        = "date_utc";                        // container ascii-string format:^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}([+-]\d{2}:\d{2}|Z)$
 char const * const default_duration                = "default_duration";                // track unsigned-integer
 char const * const default_track                   = "default_track";                   // track boolean
 char const * const display_dimensions              = "display_dimensions";              // track ascii-string format:^\d+x\d+$
@@ -36,10 +38,12 @@ char const * const duration                        = "duration";
 char const * const enabled_track                   = "enabled_track";                   // track boolean
 char const * const forced_track                    = "forced_track";                    // track boolean
 char const * const language                        = "language";                        // track ascii-string format:^\w{3}$
+char const * const minimum_timestamp               = "minimum_timestamp";               // track unsigned-integer
 char const * const mpeg4_p10_es_video              = "mpeg4_p10_es_video";              // track boolean
 char const * const mpeg4_p10_video                 = "mpeg4_p10_video";                 // track boolean
 char const * const mpegh_p2_es_video               = "mpegh_p2_es_video";               // track boolean
 char const * const mpegh_p2_video                  = "mpegh_p2_video";                  // track boolean
+char const * const muxing_application              = "muxing_application";              // container unicode-string
 char const * const next_segment_uid                = "next_segment_uid";                // container ascii-string format:^[0-9A-F]{32}$
 char const * const number                          = "number";                          // container unsigned-integer
 char const * const other_file                      = "other_file";                      // container unicoode-string
@@ -55,11 +59,13 @@ char const * const segment_uid                     = "segment_uid";
 char const * const stereo_mode                     = "stereo_mode";                     // track unsigned-integer
 char const * const stream_id                       = "stream_id";                       // track unsigned-integer
 char const * const sub_stream_id                   = "sub_stream_id";                   // track unsigned-integer
+char const * const teletext_page                   = "teletext_page";                   // track unsigned-integer
 char const * const text_subtitles                  = "text_subtitles";                  // track boolean
 char const * const title                           = "title";                           // container unicoode-string
 char const * const track_name                      = "track_name";                      // track unicoode-string
 char const * const ts_pid                          = "ts_pid";                          // track unsigned-integer
 char const * const uid                             = "uid";                             // track attachments unsigned-integer
+char const * const writing_application             = "writing_application";             // container unicode-string
 
 using verbose_info_t = std::vector<std::pair<std::string, nlohmann::json>>;
 
