@@ -198,30 +198,6 @@ struct avc_frame_t {
   }
 };
 
-class nalu_size_length_x: public mtx::exception {
-protected:
-  unsigned int m_required_length;
-
-public:
-  nalu_size_length_x(unsigned int required_length)
-    : m_required_length(required_length)
-  {
-  }
-  virtual ~nalu_size_length_x() throw() { }
-
-  virtual const char *what() const throw() {
-    return "'NALU size' length too small";
-  }
-
-  virtual std::string error() const throw() {
-    return (boost::format("length of the 'NALU size' field too small: need at least %1% bytes") % m_required_length).str();
-  }
-
-  virtual unsigned int get_required_length() const {
-    return m_required_length;
-  }
-};
-
 class avcc_c {
 public:
   unsigned int m_profile_idc, m_profile_compat, m_level_idc, m_nalu_size_length;
@@ -427,7 +403,6 @@ protected:
   bool flush_decision(slice_info_t &si, slice_info_t &ref);
   void flush_incomplete_frame();
   void flush_unhandled_nalus();
-  void write_nalu_size(unsigned char *buffer, size_t size, int this_nalu_size_length = -1) const;
   memory_cptr create_nalu_with_size(const memory_cptr &src, bool add_extra_data = false);
   void remove_trailing_zero_bytes(memory_c &memory);
   void init_nalu_names();
