@@ -26,6 +26,8 @@
 #include "info/qt_ui.h"
 #include "info/mkvinfo.h"
 
+#include <QIcon>
+#include <QList>
 #include <QMessageBox>
 #include <QMimeData>
 #include <QMouseEvent>
@@ -52,6 +54,12 @@ main_window_c::main_window_c():
 
   setupUi(this);
 
+  QIcon icon;
+  for (auto size : QList<int>{} << 32 << 48 << 64 << 128 << 256)
+    icon.addFile(QString{":/icons/%1x%1/mkvinfo.png"}.arg(size));
+
+  setWindowIcon(icon);
+
   connect(action_Open, SIGNAL(triggered()), this, SLOT(open()));
   connect(action_Save_text_file, SIGNAL(triggered()), this,
           SLOT(save_text_file()));
@@ -159,6 +167,9 @@ main_window_c::show_error(const QString &msg) {
 
 void
 main_window_c::parse_file(const QString &file_name) {
+  auto title = Q("%1 – mkvinfo").arg(QFileInfo{file_name}.fileName());
+  setWindowTitle(title);
+
   tree->setEnabled(false);
   tree->clear();
 
