@@ -17,6 +17,8 @@
 
 #include "common/common_pch.h"
 
+#include <ctime>
+
 #include "common/codec.h"
 #include "common/content_decoder.h"
 #include "common/dts.h"
@@ -193,8 +195,9 @@ private:
   using deferred_positions_t = std::map<deferred_l1_type_e, std::vector<int64_t> >;
   deferred_positions_t m_deferred_l1_positions, m_handled_l1_positions;
 
-  std::string m_writing_app, m_muxing_app;
+  std::string m_writing_app, m_raw_writing_app, m_muxing_app;
   int64_t m_writing_app_ver;
+  std::time_t m_muxing_date_epoch{};
 
   memory_cptr m_segment_uid, m_next_segment_uid, m_previous_segment_uid;
 
@@ -204,7 +207,7 @@ private:
 
   file_status_e m_file_status;
 
-  bool m_opus_experimental_warning_shown;
+  bool m_opus_experimental_warning_shown, m_regenerate_chapter_uids;
 
 public:
   kax_reader_c(const track_info_c &ti, const mm_io_cptr &in);
@@ -298,10 +301,12 @@ protected:
 
   virtual void process_simple_block(KaxCluster *cluster, KaxSimpleBlock *block_simple);
   virtual void process_block_group(KaxCluster *cluster, KaxBlockGroup *block_group);
-  virtual void process_block_group_common(KaxBlockGroup *block_group, packet_t *packet);
+  virtual void process_block_group_common(KaxBlockGroup *block_group, packet_t *packet, kax_track_t &track);
 
   void init_l1_position_storage(deferred_positions_t &storage);
   virtual bool has_deferred_element_been_processed(deferred_l1_type_e type, int64_t position);
+
+  virtual std::unordered_map<uint64_t, timestamp_c> determine_minimum_timestamps();
 };
 
 #endif  // MTX_INPUT_R_MATROSKA_H
