@@ -8,8 +8,8 @@
 #include "mkvtoolnix-gui/main_window/select_character_set_dialog.h"
 #include "mkvtoolnix-gui/merge/additional_command_line_options_dialog.h"
 #include "mkvtoolnix-gui/merge/tab.h"
+#include "mkvtoolnix-gui/util/file.h"
 #include "mkvtoolnix-gui/util/message_box.h"
-#include "mkvtoolnix-gui/util/process.h"
 #include "mkvtoolnix-gui/util/settings.h"
 #include "mkvtoolnix-gui/util/widget.h"
 
@@ -225,7 +225,13 @@ Tab::onTitleChanged(QString newValue) {
 
 void
 Tab::setDestination(QString const &newValue) {
-  m_config.m_destination = Util::removeInvalidPathCharacters(newValue);
+  QString prefix;
+#if defined(SYS_WINDOWS)
+  if (newValue.startsWith(Q(":")))
+    prefix = Q(":");
+#endif
+
+  m_config.m_destination = prefix + Util::removeInvalidPathCharacters(newValue);
   if (!m_config.m_destination.isEmpty()) {
     auto &settings           = Util::Settings::get();
     settings.m_lastOutputDir = QFileInfo{ newValue }.absoluteDir();
