@@ -12,6 +12,7 @@
 #include "mkvtoolnix-gui/merge/tool.h"
 #include "mkvtoolnix-gui/forms/main_window/main_window.h"
 #include "mkvtoolnix-gui/forms/merge/tab.h"
+#include "mkvtoolnix-gui/util/file.h"
 #include "mkvtoolnix-gui/util/file_dialog.h"
 #include "mkvtoolnix-gui/util/message_box.h"
 #include "mkvtoolnix-gui/util/option_file.h"
@@ -55,7 +56,8 @@ Tab::Tab(QWidget *parent)
   , m_selectAllSubtitlesTracksAction{new QAction{this}}
   , m_openFilesInMediaInfoAction{new QAction{this}}
   , m_openTracksInMediaInfoAction{new QAction{this}}
-  , m_selectAllAttachedFilesAction{new QAction{this}}
+  , m_enableAllAttachedFilesAction{new QAction{this}}
+  , m_disableAllAttachedFilesAction{new QAction{this}}
   , m_enableSelectedAttachedFilesAction{new QAction{this}}
   , m_disableSelectedAttachedFilesAction{new QAction{this}}
   , m_filesMenu{new QMenu{this}}
@@ -331,6 +333,11 @@ Tab::isReadyForMerging() {
     return false;
   }
 
+  if (m_config.m_destination != Util::removeInvalidPathCharacters(m_config.m_destination)) {
+    Util::MessageBox::critical(this)->title(QY("Cannot start merging")).text(QY("The output file name is invalid and must be fixed before you can start merging or add a job to the job queue.")).exec();
+    return false;
+  }
+
   return true;
 }
 
