@@ -95,7 +95,16 @@ Track::isRegular()
 bool
 Track::isPropertySet(QString const &property)
   const {
-  return m_properties.contains(property) && !m_properties.value(property).isEmpty();
+  if (!m_properties.contains(property))
+    return false;
+
+  auto var = m_properties.value(property);
+
+  return var.isNull()                            ? false
+       : !var.isValid()                          ? false
+       : var.canConvert(QMetaType::QVariantList) ? !var.toList().isEmpty()
+       : var.canConvert(QMetaType::QString)      ? !var.toString().isEmpty()
+       :                                           true;
 }
 
 void
@@ -105,17 +114,18 @@ Track::setDefaults() {
   if (isAudio() && settings.m_setAudioDelayFromFileName)
     m_delay = extractAudioDelayFromFileName();
 
-  m_forcedTrackFlag        = m_properties["forced_track"]  == Q("1") ? 1 : 0;
+  m_forcedTrackFlag        = m_properties.value("forced_track").toBool() ? 1 : 0;
   m_forcedTrackFlagWasSet  = m_forcedTrackFlag == 1;
-  m_defaultTrackFlagWasSet = m_properties[Q("default_track")] == "1";
-  m_name                   = m_properties[Q("track_name")];
+  m_defaultTrackFlagWasSet = m_properties.value("default_track").toBool();
+  m_defaultTrackFlagWasPresent = m_properties.contains("default_track");
+  m_name                   = m_properties.value("track_name").toString();
   m_nameWasPresent         = !m_name.isEmpty();
-  m_cropping               = m_properties[Q("cropping")];
-  m_aacSbrWasDetected      = m_properties["aac_is_sbr"].contains(QRegExp{"1|true"});
-  m_stereoscopy            = m_properties[Q("stereo_mode")].isEmpty() ? 0 : m_properties[Q("stereo_mode")].toUInt() + 1;
-  m_characterSet           = (m_properties[Q("text_subtitles")] == Q("1")) && m_file && (m_file->m_type != FILE_TYPE_MATROSKA) ? settings.m_defaultSubtitleCharset : Q("");
+  m_cropping               = m_properties.value("cropping").toString();
+  m_aacSbrWasDetected      = m_properties.value("aac_is_sbr").toString().contains(QRegExp{"1|true"});
+  m_stereoscopy            = m_properties.contains("stereo_mode") ? m_properties.value("stereo_mode").toUInt() + 1 : 0;
+  m_characterSet           = m_properties.value("text_subtitles").toBool() && m_file && (m_file->m_type != FILE_TYPE_MATROSKA) ? settings.m_defaultSubtitleCharset : Q("");
 
-  auto language = m_properties[Q("language")];
+  auto language = m_properties.value("language").toString();
   if (language.isEmpty())
     language = isAudio()     ? settings.m_defaultAudioTrackLanguage
              : isVideo()     ? settings.m_defaultVideoTrackLanguage
@@ -127,7 +137,7 @@ Track::setDefaults() {
     m_language = to_qs(g_iso639_languages[idx].iso639_2_code);
 
   QRegExp re_displayDimensions{"^(\\d+)x(\\d+)$"};
-  if (-1 != re_displayDimensions.indexIn(m_properties[Q("display_dimensions")])) {
+  if (-1 != re_displayDimensions.indexIn(m_properties.value("display_dimensions").toString())) {
     m_displayWidth  = re_displayDimensions.cap(1);
     m_displayHeight = re_displayDimensions.cap(2);
   }
@@ -163,42 +173,43 @@ Track::saveSettings(Util::ConfigFile &settings)
   for (auto &track : m_appendedTracks)
     appendedTracks << QString::number(reinterpret_cast<qulonglong>(track));
 
-  settings.setValue("objectID",               reinterpret_cast<qulonglong>(this));
-  settings.setValue("appendedTo",             reinterpret_cast<qulonglong>(m_appendedTo));
-  settings.setValue("appendedTracks",         appendedTracks);
-  settings.setValue("type",                   m_type);
-  settings.setValue("id",                     static_cast<qulonglong>(m_id));
-  settings.setValue("muxThis",                m_muxThis);
-  settings.setValue("setAspectRatio",         m_setAspectRatio);
-  settings.setValue("defaultTrackFlagWasSet", m_defaultTrackFlagWasSet);
-  settings.setValue("forcedTrackFlagWasSet",  m_forcedTrackFlagWasSet);
-  settings.setValue("aacSbrWasDetected",      m_aacSbrWasDetected);
-  settings.setValue("nameWasPresent",         m_nameWasPresent);
-  settings.setValue("fixBitstreamTimingInfo", m_fixBitstreamTimingInfo);
-  settings.setValue("name",                   m_name);
-  settings.setValue("codec",                  m_codec);
-  settings.setValue("language",               m_language);
-  settings.setValue("tags",                   m_tags);
-  settings.setValue("delay",                  m_delay);
-  settings.setValue("stretchBy",              m_stretchBy);
-  settings.setValue("defaultDuration",        m_defaultDuration);
-  settings.setValue("timecodes",              m_timecodes);
-  settings.setValue("aspectRatio",            m_aspectRatio);
-  settings.setValue("displayWidth",           m_displayWidth);
-  settings.setValue("displayHeight",          m_displayHeight);
-  settings.setValue("cropping",               m_cropping);
-  settings.setValue("characterSet",           m_characterSet);
-  settings.setValue("additionalOptions",      m_additionalOptions);
-  settings.setValue("defaultTrackFlag",       m_defaultTrackFlag);
-  settings.setValue("forcedTrackFlag",        m_forcedTrackFlag);
-  settings.setValue("stereoscopy",            m_stereoscopy);
-  settings.setValue("naluSizeLength",         m_naluSizeLength);
-  settings.setValue("cues",                   m_cues);
-  settings.setValue("aacIsSBR",               m_aacIsSBR);
-  settings.setValue("reduceAudioToCore",      m_reduceAudioToCore);
-  settings.setValue("compression",            m_compression);
-  settings.setValue("size",                   static_cast<qulonglong>(m_size));
-  settings.setValue("attachmentDescription",  m_attachmentDescription);
+  settings.setValue("objectID",                   reinterpret_cast<qulonglong>(this));
+  settings.setValue("appendedTo",                 reinterpret_cast<qulonglong>(m_appendedTo));
+  settings.setValue("appendedTracks",             appendedTracks);
+  settings.setValue("type",                       m_type);
+  settings.setValue("id",                         static_cast<qulonglong>(m_id));
+  settings.setValue("muxThis",                    m_muxThis);
+  settings.setValue("setAspectRatio",             m_setAspectRatio);
+  settings.setValue("defaultTrackFlagWasSet",     m_defaultTrackFlagWasSet);
+  settings.setValue("defaultTrackFlagWasPresent", m_defaultTrackFlagWasPresent);
+  settings.setValue("forcedTrackFlagWasSet",      m_forcedTrackFlagWasSet);
+  settings.setValue("aacSbrWasDetected",          m_aacSbrWasDetected);
+  settings.setValue("nameWasPresent",             m_nameWasPresent);
+  settings.setValue("fixBitstreamTimingInfo",     m_fixBitstreamTimingInfo);
+  settings.setValue("name",                       m_name);
+  settings.setValue("codec",                      m_codec);
+  settings.setValue("language",                   m_language);
+  settings.setValue("tags",                       m_tags);
+  settings.setValue("delay",                      m_delay);
+  settings.setValue("stretchBy",                  m_stretchBy);
+  settings.setValue("defaultDuration",            m_defaultDuration);
+  settings.setValue("timecodes",                  m_timecodes);
+  settings.setValue("aspectRatio",                m_aspectRatio);
+  settings.setValue("displayWidth",               m_displayWidth);
+  settings.setValue("displayHeight",              m_displayHeight);
+  settings.setValue("cropping",                   m_cropping);
+  settings.setValue("characterSet",               m_characterSet);
+  settings.setValue("additionalOptions",          m_additionalOptions);
+  settings.setValue("defaultTrackFlag",           m_defaultTrackFlag);
+  settings.setValue("forcedTrackFlag",            m_forcedTrackFlag);
+  settings.setValue("stereoscopy",                m_stereoscopy);
+  settings.setValue("naluSizeLength",             m_naluSizeLength);
+  settings.setValue("cues",                       m_cues);
+  settings.setValue("aacIsSBR",                   m_aacIsSBR);
+  settings.setValue("reduceAudioToCore",          m_reduceAudioToCore);
+  settings.setValue("compression",                m_compression);
+  settings.setValue("size",                       static_cast<qulonglong>(m_size));
+  settings.setValue("attachmentDescription",      m_attachmentDescription);
 }
 
 void
@@ -209,40 +220,41 @@ Track::loadSettings(MuxConfig::Loader &l) {
   if ((0 >= objectID) || l.objectIDToTrack.contains(objectID))
     throw InvalidSettingsX{};
 
-  l.objectIDToTrack[objectID] = this;
-  m_type                      = static_cast<Type>(l.settings.value("type").toInt());
-  m_id                        = l.settings.value("id").toULongLong();
-  m_muxThis                   = l.settings.value("muxThis").toBool();
-  m_setAspectRatio            = l.settings.value("setAspectRatio").toBool();
-  m_defaultTrackFlagWasSet    = l.settings.value("defaultTrackFlagWasSet").toBool();
-  m_forcedTrackFlagWasSet     = l.settings.value("forcedTrackFlagWasSet").toBool();
-  m_aacSbrWasDetected         = l.settings.value("aacSbrWasDetected").toBool();
-  m_name                      = l.settings.value("name").toString();
-  m_nameWasPresent            = l.settings.value("nameWasPresent").toBool();
-  m_fixBitstreamTimingInfo    = l.settings.value("fixBitstreamTimingInfo").toBool();
-  m_codec                     = l.settings.value("codec").toString();
-  m_language                  = l.settings.value("language").toString();
-  m_tags                      = l.settings.value("tags").toString();
-  m_delay                     = l.settings.value("delay").toString();
-  m_stretchBy                 = l.settings.value("stretchBy").toString();
-  m_defaultDuration           = l.settings.value("defaultDuration").toString();
-  m_timecodes                 = l.settings.value("timecodes").toString();
-  m_aspectRatio               = l.settings.value("aspectRatio").toString();
-  m_displayWidth              = l.settings.value("displayWidth").toString();
-  m_displayHeight             = l.settings.value("displayHeight").toString();
-  m_cropping                  = l.settings.value("cropping").toString();
-  m_characterSet              = l.settings.value("characterSet").toString();
-  m_additionalOptions         = l.settings.value("additionalOptions").toString();
-  m_defaultTrackFlag          = l.settings.value("defaultTrackFlag").toInt();
-  m_forcedTrackFlag           = l.settings.value("forcedTrackFlag").toInt();
-  m_stereoscopy               = l.settings.value("stereoscopy").toInt();
-  m_naluSizeLength            = l.settings.value("naluSizeLength").toInt();
-  m_cues                      = l.settings.value("cues").toInt();
-  m_aacIsSBR                  = l.settings.value("aacIsSBR").toInt();
-  m_reduceAudioToCore         = l.settings.value("reduceAudioToCore").toBool();
-  m_compression               = static_cast<Compression>(l.settings.value("compression").toInt());
-  m_size                      = l.settings.value("size").toULongLong();
-  m_attachmentDescription     = l.settings.value("attachmentDescription").toString();
+  l.objectIDToTrack[objectID]  = this;
+  m_type                       = static_cast<Type>(l.settings.value("type").toInt());
+  m_id                         = l.settings.value("id").toULongLong();
+  m_muxThis                    = l.settings.value("muxThis").toBool();
+  m_setAspectRatio             = l.settings.value("setAspectRatio").toBool();
+  m_defaultTrackFlagWasSet     = l.settings.value("defaultTrackFlagWasSet").toBool();
+  m_defaultTrackFlagWasPresent = l.settings.value("defaultTrackFlagWasPresent").toBool() || m_defaultTrackFlagWasSet;
+  m_forcedTrackFlagWasSet      = l.settings.value("forcedTrackFlagWasSet").toBool();
+  m_aacSbrWasDetected          = l.settings.value("aacSbrWasDetected").toBool();
+  m_name                       = l.settings.value("name").toString();
+  m_nameWasPresent             = l.settings.value("nameWasPresent").toBool();
+  m_fixBitstreamTimingInfo     = l.settings.value("fixBitstreamTimingInfo").toBool();
+  m_codec                      = l.settings.value("codec").toString();
+  m_language                   = l.settings.value("language").toString();
+  m_tags                       = l.settings.value("tags").toString();
+  m_delay                      = l.settings.value("delay").toString();
+  m_stretchBy                  = l.settings.value("stretchBy").toString();
+  m_defaultDuration            = l.settings.value("defaultDuration").toString();
+  m_timecodes                  = l.settings.value("timecodes").toString();
+  m_aspectRatio                = l.settings.value("aspectRatio").toString();
+  m_displayWidth               = l.settings.value("displayWidth").toString();
+  m_displayHeight              = l.settings.value("displayHeight").toString();
+  m_cropping                   = l.settings.value("cropping").toString();
+  m_characterSet               = l.settings.value("characterSet").toString();
+  m_additionalOptions          = l.settings.value("additionalOptions").toString();
+  m_defaultTrackFlag           = l.settings.value("defaultTrackFlag").toInt();
+  m_forcedTrackFlag            = l.settings.value("forcedTrackFlag").toInt();
+  m_stereoscopy                = l.settings.value("stereoscopy").toInt();
+  m_naluSizeLength             = l.settings.value("naluSizeLength").toInt();
+  m_cues                       = l.settings.value("cues").toInt();
+  m_aacIsSBR                   = l.settings.value("aacIsSBR").toInt();
+  m_reduceAudioToCore          = l.settings.value("reduceAudioToCore").toBool();
+  m_compression                = static_cast<Compression>(l.settings.value("compression").toInt());
+  m_size                       = l.settings.value("size").toULongLong();
+  m_attachmentDescription      = l.settings.value("attachmentDescription").toString();
 
   if (   (TypeMin > m_type)        || (TypeMax < m_type)
       || (CompMin > m_compression) || (CompMax < m_compression))
