@@ -21,10 +21,10 @@ namespace {
 QFont
 defaultUiFont() {
   auto font         = App::font();
-  auto logicalDPI   = App::primaryScreen()->logicalDotsPerInch();
-  auto minPointSize = static_cast<int>(9 + (std::max(logicalDPI, 95.) - 95 + 5) * 3 / 25);
+  // auto logicalDPI   = App::primaryScreen()->logicalDotsPerInch();
+  // auto minPointSize = static_cast<int>(9 + (std::max(logicalDPI, 95.) - 95 + 5) * 3 / 25);
 
-  font.setPointSize(std::max(font.pointSize(), minPointSize));
+  // font.setPointSize(std::max(font.pointSize(), minPointSize));
 
 #if defined(SYS_WINDOWS)
   font.setFamily(Q("Segoe UI"));
@@ -126,7 +126,7 @@ Settings::convertOldSettings() {
   auto mergeAlwaysAddDroppedFiles = reg->value("mergeAlwaysAddDroppedFiles");
 
   if (mergeAlwaysAddDroppedFiles.isValid())
-    reg->setValue("mergeAddingAppendingFilesPolicy", static_cast<int>(AddingAppendingFilesPolicy::Add));
+    reg->setValue("mergeAddingAppendingFilesPolicy", static_cast<int>(MergeAddingAppendingFilesPolicy::Add));
 
   reg->remove("mergeAlwaysAddDroppedFiles");
   reg->endGroup();
@@ -181,17 +181,20 @@ Settings::load() {
 
   m_setAudioDelayFromFileName          = reg.value("setAudioDelayFromFileName", true).toBool();
   m_autoSetFileTitle                   = reg.value("autoSetFileTitle",          true).toBool();
+  m_autoClearFileTitle                 = reg.value("autoClearFileTitle",        m_autoSetFileTitle).toBool();
   m_clearMergeSettings                 = static_cast<ClearMergeSettingsAction>(reg.value("clearMergeSettings", static_cast<int>(ClearMergeSettingsAction::None)).toInt());
   m_disableCompressionForAllTrackTypes = reg.value("disableCompressionForAllTrackTypes", false).toBool();
   m_disableDefaultTrackForSubtitles    = reg.value("disableDefaultTrackForSubtitles",    false).toBool();
   m_mergeAlwaysShowOutputFileControls  = reg.value("mergeAlwaysShowOutputFileControls",  true).toBool();
   m_mergeTrackPropertiesLayout         = static_cast<TrackPropertiesLayout>(reg.value("mergeTrackPropertiesLayout", static_cast<int>(TrackPropertiesLayout::HorizontalScrollArea)).toInt());
-  m_mergeAddingAppendingFilesPolicy    = static_cast<AddingAppendingFilesPolicy>(reg.value("mergeAddingAppendingFilesPolicy", static_cast<int>(AddingAppendingFilesPolicy::Ask)).toInt());
+  m_mergeAddingAppendingFilesPolicy    = static_cast<MergeAddingAppendingFilesPolicy>(reg.value("mergeAddingAppendingFilesPolicy", static_cast<int>(MergeAddingAppendingFilesPolicy::Ask)).toInt());
+  m_headerEditorDroppedFilesPolicy     = static_cast<HeaderEditorDroppedFilesPolicy>(reg.value("headerEditorDroppedFilesPolicy", static_cast<int>(HeaderEditorDroppedFilesPolicy::Ask)).toInt());
 
-  m_uniqueOutputFileNames              = reg.value("uniqueOutputFileNames",     true).toBool();
   m_outputFileNamePolicy               = static_cast<OutputFileNamePolicy>(reg.value("outputFileNamePolicy", static_cast<int>(ToSameAsFirstInputFile)).toInt());
   m_relativeOutputDir                  = QDir{reg.value("relativeOutputDir").toString()};
   m_fixedOutputDir                     = QDir{reg.value("fixedOutputDir").toString()};
+  m_uniqueOutputFileNames              = reg.value("uniqueOutputFileNames",   true).toBool();
+  m_autoClearOutputFileName            = reg.value("autoClearOutputFileName", m_outputFileNamePolicy != DontSetOutputFileName).toBool();
 
   m_enableMuxingTracksByLanguage       = reg.value("enableMuxingTracksByLanguage", false).toBool();
   m_enableMuxingAllVideoTracks         = reg.value("enableMuxingAllVideoTracks", true).toBool();
@@ -204,6 +207,8 @@ Settings::load() {
   m_switchToJobOutputAfterStarting     = reg.value("switchToJobOutputAfterStarting", false).toBool();
   m_resetJobWarningErrorCountersOnExit = reg.value("resetJobWarningErrorCountersOnExit", false).toBool();
   m_jobRemovalPolicy                   = static_cast<JobRemovalPolicy>(reg.value("jobRemovalPolicy", static_cast<int>(JobRemovalPolicy::Never)).toInt());
+  m_removeOldJobs                      = reg.value("removeOldJobs",                                  true).toBool();
+  m_removeOldJobsDays                  = reg.value("removeOldJobsDays",                              14).toInt();
 
   m_disableAnimations                  = reg.value("disableAnimations", false).toBool();
   m_showToolSelector                   = reg.value("showToolSelector", true).toBool();
@@ -293,6 +298,7 @@ Settings::loadRunProgramConfigurations(QSettings &reg) {
     auto cfg = std::make_shared<RunProgramConfig>();
 
     reg.beginGroup(group);
+    cfg->m_active      = reg.value("active", true).toBool();
     cfg->m_commandLine = reg.value("commandLine").toStringList();
     cfg->m_forEvents   = static_cast<RunProgramForEvents>(reg.value("forEvents").value<int>());
     reg.endGroup();
@@ -336,17 +342,20 @@ Settings::save()
 
   reg.setValue("setAudioDelayFromFileName",          m_setAudioDelayFromFileName);
   reg.setValue("autoSetFileTitle",                   m_autoSetFileTitle);
+  reg.setValue("autoClearFileTitle",                 m_autoClearFileTitle);
   reg.setValue("clearMergeSettings",                 static_cast<int>(m_clearMergeSettings));
   reg.setValue("disableCompressionForAllTrackTypes", m_disableCompressionForAllTrackTypes);
   reg.setValue("disableDefaultTrackForSubtitles",    m_disableDefaultTrackForSubtitles);
   reg.setValue("mergeAlwaysShowOutputFileControls",  m_mergeAlwaysShowOutputFileControls);
   reg.setValue("mergeTrackPropertiesLayout",         static_cast<int>(m_mergeTrackPropertiesLayout));
   reg.setValue("mergeAddingAppendingFilesPolicy",    static_cast<int>(m_mergeAddingAppendingFilesPolicy));
+  reg.setValue("headerEditorDroppedFilesPolicy",     static_cast<int>(m_headerEditorDroppedFilesPolicy));
 
   reg.setValue("outputFileNamePolicy",               static_cast<int>(m_outputFileNamePolicy));
   reg.setValue("relativeOutputDir",                  m_relativeOutputDir.path());
   reg.setValue("fixedOutputDir",                     m_fixedOutputDir.path());
   reg.setValue("uniqueOutputFileNames",              m_uniqueOutputFileNames);
+  reg.setValue("autoClearOutputFileName",            m_autoClearOutputFileName);
 
   reg.setValue("enableMuxingTracksByLanguage",       m_enableMuxingTracksByLanguage);
   reg.setValue("enableMuxingAllVideoTracks",         m_enableMuxingAllVideoTracks);
@@ -359,6 +368,8 @@ Settings::save()
   reg.setValue("switchToJobOutputAfterStarting",     m_switchToJobOutputAfterStarting);
   reg.setValue("resetJobWarningErrorCountersOnExit", m_resetJobWarningErrorCountersOnExit);
   reg.setValue("jobRemovalPolicy",                   static_cast<int>(m_jobRemovalPolicy));
+  reg.setValue("removeOldJobs",                      m_removeOldJobs);
+  reg.setValue("removeOldJobsDays",                  m_removeOldJobsDays);
 
   reg.setValue("disableAnimations",                  m_disableAnimations);
   reg.setValue("showToolSelector",                   m_showToolSelector);
@@ -424,6 +435,7 @@ Settings::saveRunProgramConfigurations(QSettings &reg)
   auto idx = 0;
   for (auto const &cfg : m_runProgramConfigurations) {
     reg.beginGroup(Q("%1").arg(++idx, 4, 10, Q('0')));
+    reg.setValue("active",      cfg->m_active);
     reg.setValue("commandLine", cfg->m_commandLine);
     reg.setValue("forEvents",   static_cast<int>(cfg->m_forEvents));
     reg.endGroup();
