@@ -66,7 +66,7 @@ public:
     RemoveInputFiles,
   };
 
-  enum class AddingAppendingFilesPolicy {
+  enum class MergeAddingAppendingFilesPolicy {
     Ask,
     Add,
     AddToNew,
@@ -75,6 +75,12 @@ public:
     AddAdditionalParts,
   };
 
+  enum class HeaderEditorDroppedFilesPolicy {
+    Ask,
+    Open,
+    AddAttachments,
+  };
+
   enum class TrackPropertiesLayout {
     HorizontalScrollArea,
     HorizontalTwoColumns,
@@ -83,6 +89,7 @@ public:
 
   class RunProgramConfig {
   public:
+    bool m_active{true};
     QStringList m_commandLine;
     RunProgramForEvents m_forEvents{};
 
@@ -98,19 +105,22 @@ public:
   ProcessPriority m_priority;
   QTabWidget::TabPosition m_tabPosition;
   QDir m_lastOpenDir, m_lastOutputDir, m_lastConfigDir;
-  bool m_setAudioDelayFromFileName, m_autoSetFileTitle, m_disableCompressionForAllTrackTypes, m_disableDefaultTrackForSubtitles, m_mergeAlwaysShowOutputFileControls, m_dropLastChapterFromBlurayPlaylist;
+  bool m_setAudioDelayFromFileName, m_autoSetFileTitle, m_autoClearFileTitle, m_disableCompressionForAllTrackTypes, m_disableDefaultTrackForSubtitles, m_mergeAlwaysShowOutputFileControls, m_dropLastChapterFromBlurayPlaylist;
   ClearMergeSettingsAction m_clearMergeSettings;
-  AddingAppendingFilesPolicy m_mergeAddingAppendingFilesPolicy;
+  MergeAddingAppendingFilesPolicy m_mergeAddingAppendingFilesPolicy;
+  HeaderEditorDroppedFilesPolicy m_headerEditorDroppedFilesPolicy;
   TrackPropertiesLayout m_mergeTrackPropertiesLayout;
 
   OutputFileNamePolicy m_outputFileNamePolicy;
   QDir m_relativeOutputDir, m_fixedOutputDir;
-  bool m_uniqueOutputFileNames;
+  bool m_uniqueOutputFileNames, m_autoClearOutputFileName;
 
   ScanForPlaylistsPolicy m_scanForPlaylistsPolicy;
   unsigned int m_minimumPlaylistDuration;
 
   JobRemovalPolicy m_jobRemovalPolicy;
+  bool m_removeOldJobs;
+  int m_removeOldJobsDays;
   bool m_useDefaultJobDescription, m_showOutputOfAllJobs, m_switchToJobOutputAfterStarting, m_resetJobWarningErrorCountersOnExit;
 
   bool m_checkForUpdates;
