@@ -1,16 +1,41 @@
 #include "common/common_pch.h"
 
 #include <QDateTime>
+#include <QDebug>
 #include <QRegularExpression>
 #include <QString>
 #include <QStringList>
 
+#include "common/list_utils.h"
 #include "common/qt.h"
 #include "common/strings/editing.h"
 #include "mkvtoolnix-gui/util/string.h"
 
 namespace mtx { namespace gui { namespace Util {
 
+DeferredRegularExpression::DeferredRegularExpression(QString const &pattern,
+                                                     QRegularExpression::PatternOptions options)
+  : m_pattern{pattern}
+  , m_options{options}
+{
+}
+
+DeferredRegularExpression::~DeferredRegularExpression() {
+}
+
+QRegularExpression &
+DeferredRegularExpression::operator *() {
+  if (!m_re) {
+    m_re.reset(new QRegularExpression{m_pattern, m_options});
+    if (!m_re->isValid())
+      qDebug() << "mtxgui::DeferredRegularExpression: compilation failed for pattern" << m_pattern << "at position" << m_re->patternErrorOffset() << ":" << m_re->errorString();
+  }
+
+  return *m_re;
+}
+
+// ----------------------------------------------------------------------
+
 static QString
 escapeMkvtoolnix(QString const &source) {
   if (source.isEmpty())
@@ -102,7 +127,7 @@ escapeShellWindows(QString const &source) {
   if (source.isEmpty())
     return Q("^\"^\"");
 
-  if (!source.contains(QRegExp{"[\\w+,\\-./:=@]"}))
+  if (!source.contains(QRegularExpression{"[^\\w+,\\-./:=@]"}))
     return source;
 
   auto copy = QString{'"'};
@@ -141,6 +166,18 @@ escapeShellWindowsProgram(QString const &source) {
   return source;
 }
 
+static QString
+escapeKeyboardShortcuts(QString const &text) {
+  auto copy = text;
+  return copy.replace(Q("&"), Q("&&"));
+}
+
+static QString
+unescapeKeyboardShortcuts(QString const &text) {
+  auto copy = text;
+  return copy.replace(Q("&&"), Q("&"));
+}
+
 QString
 escape(QString const &source,
        EscapeMode mode) {
@@ -148,15 +185,17 @@ escape(QString const &source,
        : EscapeShellUnix           == mode ? escapeShellUnix(source)
        : EscapeShellCmdExeArgument == mode ? escapeShellWindows(source)
        : EscapeShellCmdExeProgram  == mode ? escapeShellWindowsProgram(source)
+       : EscapeKeyboardShortcuts   == mode ? escapeKeyboardShortcuts(source)
        :                                     source;
 }
 
 QString
 unescape(QString const &source,
          EscapeMode mode) {
-  Q_ASSERT(EscapeMkvtoolnix == mode);
+  Q_ASSERT(mtx::included_in(mode, EscapeMkvtoolnix, EscapeKeyboardShortcuts));
 
-  return unescapeMkvtoolnix(source);
+  return EscapeKeyboardShortcuts == mode ? unescapeKeyboardShortcuts(source)
+       :                                   unescapeMkvtoolnix(source);
 }
 
 QStringList
