@@ -3,6 +3,8 @@
 
 #include "common/common_pch.h"
 
+#include <QRegularExpression>
+
 class QString;
 class QStringList;
 
@@ -13,6 +15,7 @@ enum EscapeMode {
   EscapeShellUnix,
   EscapeShellCmdExeArgument,
   EscapeShellCmdExeProgram,
+  EscapeKeyboardShortcuts,
   DontEscape,
 #if defined(SYS_WINDOWS)
   EscapeShellNative = EscapeShellCmdExeArgument,
@@ -33,6 +36,18 @@ QString displayableDate(QDateTime const &date);
 
 QString itemFlagsToString(Qt::ItemFlags const &flags);
 
+class DeferredRegularExpression {
+private:
+  std::unique_ptr<QRegularExpression> m_re;
+  QString m_pattern;
+  QRegularExpression::PatternOptions m_options;
+
+public:
+  DeferredRegularExpression(QString const &pattern, QRegularExpression::PatternOptions options = QRegularExpression::NoPatternOption);
+  ~DeferredRegularExpression();
+  QRegularExpression &operator *();
+};
+
 }}}
 
 #endif  // MTX_MKVTOOLNIX_GUI_UTIL_STRING_H
